@@ -12,12 +12,13 @@ from .divisions import (
     RemoveThrowaway
 )
 from .line_nums import LineNumsPreproc, NumberedBlocksProcessor
-from .milestones import RE_MIL, MilestoneProcessor
+from .milestones import register_paragraphos, RE_MIL, MilestoneProcessor
 from .gaps_spaces import (
     CompleteSquareBrackets,
     RE_SPACE, SpaceProcessor,
     RE_LINE_LOST, LineGapProcessor,
-    RE_CHARACTER_LOST, RE_CHARACTER_ILLEGIBLE, CharacterGapProcessor
+    RE_CHARACTER_LOST, CharacterLostProcessor,
+    RE_CHARACTER_ILLEGIBLE, CharacterIllegibleProcessor
 )
 from .brackets import (
     RE_SUPPLIED, SuppliedProcessor,
@@ -25,7 +26,6 @@ from .brackets import (
 )
 from .foreign import RE_FOREIGN, ForeignProcessor
 from .misc import HetaProcessor, RE_HETA
-from .exceptions import LeidenPlusSyntaxError
 
 
 class LeidenPlus(Extension):
@@ -59,17 +59,17 @@ class LeidenPlus(Extension):
         md.inlinePatterns.register(MilestoneProcessor(RE_MIL, md), 'milestones', 120)
         md.inlinePatterns.register(SpaceProcessor(RE_SPACE, md), 'spaces', 119)
         md.inlinePatterns.register(LineGapProcessor(RE_LINE_LOST, md), 'line_gaps', 118)
-        md.inlinePatterns.register(CharacterGapProcessor(RE_CHARACTER_LOST, md, reason='lost'), 'character_lost', 117)
+        md.inlinePatterns.register(CharacterLostProcessor(RE_CHARACTER_LOST, md), 'character_lost', 117)
         md.inlinePatterns.register(ForeignProcessor(RE_FOREIGN, md), 'foreign', 116)
         md.inlinePatterns.register(ErasureProcessor(RE_ERASURE, md), 'erasure',  115)
         md.inlinePatterns.register(SuppliedProcessor(RE_SUPPLIED, md), 'supplied', 5)
-        md.inlinePatterns.register(CharacterGapProcessor(RE_CHARACTER_ILLEGIBLE, md, reason='illegible'), 'character_illegible', 4)
-        md.inlinePatterns.register(HetaProcessor(RE_HETA, md), 'heta', 49) # After UnderscoreProcessor
+        md.inlinePatterns.register(CharacterIllegibleProcessor(RE_CHARACTER_ILLEGIBLE, md), 'character_illegible', 4)
+        md.inlinePatterns.register(HetaProcessor(RE_HETA, md), 'heta', 49)  # After UnderscoreProcessor
         md.treeprocessors.register(DivisionMarkTreeproc(md), 'divison_treeproc', 120)
         md.treeprocessors.register(ColumnContainerTreeproc(md), 'col_container', 119)
         md.postprocessors.register(RemoveThrowaway(md), 'remove_throwaway', 1)
         md.postprocessors.register(TEIPostprocessor(md, configs['indent'], configs['with_root']), 'to_epidoc', 0)
-
+        register_paragraphos(md)
 
 class LeidenEscape(Extension):
 
